# Lowdash

Lowdash is a simple implementation of lodash in python.

Lowdash will provide you with a set of functions that will help to work with arrays, objects and other data structures.

# Installing

```bash
pip install lowdash
```

# Getting Started

To get started you can use the following code:

```python
from lowdash.arrays import *
compact(['a', '', 'b', None, 'c'])
# Output : ['a', 'b', 'c']
```

## Documentation Comming Soon!
